Request and Response objects
============================

.. module:: rhino

.. autoclass:: Request
   :members:

.. autoclass:: Response
   :members:

.. autoclass:: Entity
   :members:

.. autofunction:: response

.. autofunction:: ok

.. autofunction:: created

.. autofunction:: no_content

.. autofunction:: redirect

